<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\CardsInfo;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class CardsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $page_title = "All Cards";
        $data['cards']= CardsInfo::all()->sortByDesc('id');
        return view('web.admin.cards.list',compact('page_title'),$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        //
        $validator = Validator::make($request->all(), [
            'user_id'=>'required',
            'card_expire_date'=> 'required',
            'card_cvv'=> 'required',
            'card_type'=> 'required',
            'card_balance'=> 'required',
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error',$validator->messages()->first());
        }

        $card_number = generateCardNumber($request->card_type);


        $check = CardsInfo::where([
            ['user_id',$request->user_id],
            ['card_type',$request->card_type]
        ]);

        if($check->count() > 0){
            return back()->with('alert_error', 'Card already exists');
        }

        $cardInfo = new CardsInfo();
        $cardInfo->user_id = $request->user_id;
        $cardInfo->card_number = $card_number;
        $cardInfo->card_expire_date = $request->card_expire_date;
        $cardInfo->card_cvv = $request->card_cvv;
        $cardInfo->card_type = $request->card_type;
        $cardInfo->card_balance = $request->card_balance;

        if($cardInfo->save()){
            return back()->with('alert_success', 'Card added successfully');
        }

        return back()->with('alert_error', 'Opps something went wrong');


    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
