<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Deposit;
use App\Models\DomesticTransfer;
use App\Models\Transactions;
use App\Models\Wallets;
use App\Models\WireTransfer;
use Illuminate\Http\Request;

class TransactionsController extends Controller
{
    public function index($id){
        $data['trans'] = Transactions::leftjoin('users', 'users.id', '=', 'transactions.user_id')
            ->selectRaw('transactions.*,users.email')
            ->where('trans_type', $id)->orderBy('id', 'DESC')->get();
        $page_title = "Transaction";
        return view('web.admin.transaction.index', compact('page_title'), $data);
    }

    public function view_credit(Request $request, $id)
    {
        $data['credit'] = Deposit::where([
            ['reference', $id],
            ['type', 'credit']
        ])->first();
        $page_title = "View Credit";
        return view('web.admin.transaction.view.credit_view', compact('page_title'), $data);
    }

    public function view_wire_transfer(Request $request, $id)
    {
        $data["wire"] = WireTransfer::where("reference",$id)->first();
        $page_title = "View Wire Transfer";
        return view('web.admin.transaction.view.wire_view', compact('page_title'), $data);
    }

    public function view_dom_transfer(Request $request, $id)
    {
        $data["domestic"] = DomesticTransfer::where("reference", $id)->first();
        $page_title = "View Domestic Transfer";
        return view('web.admin.transaction.view.dom_view', compact('page_title'), $data);
    }

    public function view_debit(Request $request, $id)
    {
        $data['debit'] = Deposit::where([
            ['reference', $id],
            ['type', 'debit']
        ])->first();

        $page_title = "View Debit Transfer";
        return view('web.admin.transaction.view.debit_view', compact('page_title'), $data);
    }

    #SAVE TRANS
    public function save_credit(Request $request, $id)
    {
        $request->validate([
            'status' => 'required',
            'date' => 'required',
        ]);
        $deposit = Deposit::find($id);
        $deposit->status = $request->status;
        $deposit->created_at = $request->date;

        if ($deposit->save()) {
            $transaction = Transactions::where('trans_id', $deposit->reference)->first();
            $transaction->status = $deposit->status;
            $transaction->created_at = $deposit->created_at;
            if ($transaction->save()) {
                 $wallet = Wallets::where('user_id', $deposit->user_id)->first();
                $wallet->acct_balance += $transaction->amount;
                $wallet->save();
                return back()->with('alert_success', 'Credit transaction has been updated successfully');
            }
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }
    //TODO SAVE DEBIT
    public function save_debit(Request $request, $id)
    {
        $request->validate([
            'status' => 'required',
            'date' => 'required',
        ]);

        $deposit = Deposit::find($id);
        $deposit->status = $request->status;
        $deposit->created_at = $request->date;

        if ($deposit->save()) {
            $transaction = Transactions::where('trans_id', $deposit->reference)->first();
            $transaction->status = $deposit->status;
            $transaction->created_at = $deposit->created_at;
            if ($transaction->save()) {
                return back()->with('alert_success', 'Debit transaction has been updated successfully');
            }
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }
    //TODO SAVE DOMESTIC
    public function save_dom(Request $request, $id)
    {
        $request->validate([
            'status' => 'required',
            'date' => 'required',
        ]);
        $dom = DomesticTransfer::find($id);
        $dom->status = $request->status;
        $dom->created_at = $request->date;

        if ($dom->save()) {
            $transaction = Transactions::where('trans_id', $dom->reference)->first();
            $transaction->status = $request->status;
            $transaction->created_at = $dom->created_at;
            if ($transaction->save()) {
                return back()->with('alert_success', 'Domestic transaction has been updated successfully');
            }
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }
    //TODO SAVE WIRE TRANSACTION
    public function save_wire(Request $request, $id)
    {
        $request->validate([
            'status' => 'required',
            'date' => 'required',
        ]);
        $dom = WireTransfer::find($id);
        $dom->status = $request->status;
        $dom->created_at = $request->date;

        if ($dom->save()) {
            $transaction = Transactions::where('trans_id', $dom->reference)->first();
            $transaction->status = $request->status;
            $transaction->created_at = $dom->created_at;
            if ($transaction->save()) {
                return back()->with('alert_success', 'Wire transaction has been updated successfully');
            }
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }

    public function delete_trans(Request $request,$type,$id){
        if($type=='wire_transfer'){
            $delete=WireTransfer::where("reference",$id);
        }elseif ($type=='dom_transfer'){
            $delete=DomesticTransfer::where("reference",$id);
        }elseif ($type=='deposit'){
            $delete=Deposit::where("reference",$id);
        }

        $transaction=Transactions::where("trans_id",$id)->delete();
        if($transaction) {
            if($delete->delete()) {
                return back()->with('alert_success', 'Successfully deleted transaction');
            }
        }
        return back()->with('alert_error', 'Opps something went wrong');
    }
}
