<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\DomesticTransfer;
use App\Models\PaymentMethod;
use App\Models\Transactions;
use App\Models\User;
use App\Models\Wallets;
use App\Models\WireTransfer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class TransferController extends Controller
{
    public function wire_transfer(){
        $page_title = "Wire Transfer";
        return view('web.admin.transfer.wire',compact('page_title'));
    }

    public function domTransfer(){
        $page_title = "Domestic Transfer";
        return view('web.admin.transfer.dom',compact('page_title'));
    }

    public function payment_methodView(){
        $page_title = "Payment Method";
        $data['payment_method'] = PaymentMethod::all()->sortByDesc('id');
        return view('web.admin.payment_method',compact('page_title'),$data);
    }

    //TODO SAVE WIRE TRANSFER FROM ADMIN
    public function wire_transfer_send(Request $request){

        $validator = Validator::make($request->all(), [
            'amount'=>'required|numeric',
            'bank_name'=> 'required',
            'acct_name'=> 'required',
            'acct_number'=> 'required',
            'acct_type'=> 'required',
            'country'=> 'required',
            'swift_code'=> 'required',
            'routing_num'=> 'required',
            'purpose'=> 'required',
            'date'=> 'required',
            'time'=> 'required',
        ]);

        if($validator->fails()){
            return back()->with('alert_error', $validator->messages()->first());
        }


        $user= User::where("acct_number",$request->acct_number)->first();

        $wallet = Wallets::where('user_id',$user->id)->first();

        if($request->amount > $wallet->acct_balance){
            return back()->with('alert_error', "You don't have enough money");
        }

        $data = new WireTransfer();
        $data->user_id = $user->id;
        $data->reference = "WT".random_int(0000,9999);
        $data->amount = $request->amount;
        $data->bank_name = $request->bank_name;
        $data->acct_name = $request->acct_name;
        $data->acct_number = $request->acct_number;
        $data->acct_type = $request->acct_type;
        $data->acct_country = $request->country;
        $data->acct_swift = $request->swift_code;
        $data->acct_routing = $request->routing_num;
        $data->acct_remark = $request->purpose;
        $data->status = "pending";
        $data->created_at = $request->date.' '.$request->time;
        if($data->save()){

            $wallet->acct_balance -= $data->amount;

            if($wallet->save()){
                $trans = new Transactions();
                $trans->user_id = $user->id;
                $trans->trans_id = $data->reference;
                $trans->trans_reference = uniqid();
                $trans->amount = $data->amount;
                $trans->trans_type = "wire_transfer";
                $trans->created_at = $data->created_at;

                if($trans->save()){
                    return redirect(route('admin.users.view_transaction','wire_transfer'))->with('alert_success', 'Details Saved Successfully');
                }
            }

        }
        return back()->with('alert_error', 'Opps something went wrong');
    }

    //TODO SAVE DOMESTIC TRANSFER FROM ADMIN
    public function domTransferSave(Request $request){

        $validator = Validator::make($request->all(), [
            'amount'=>'required|numeric',
            'bank_name'=> 'required',
            'acct_name'=> 'required',
            'acct_number'=> 'required',
            'acct_type'=> 'required',
            'purpose'=> 'required',
            'date'=> 'required',
            'time'=> 'required',
        ]);

        if($validator->fails()){
            return back()->with('alert_error', $validator->messages()->first());
        }

        $user= User::where("acct_number",$request->acct_number)->first();

        $wallet = Wallets::where('user_id',$user->id)->first();

        if($request->amount > $wallet->acct_balance){
            return back()->with('alert_error', "You don't have enough money");
        }

        $data = new DomesticTransfer();
        $data->user_id = $user->id;
        $data->reference = "DT".random_int(0000,9999);
        $data->amount = $request->amount;
        $data->bank_name = $request->bank_name;
        $data->acct_name = $request->acct_name;
        $data->acct_number = $request->acct_number;
        $data->acct_type = $request->acct_type;
        $data->acct_remark = $request->purpose;
        $data->status = "pending";
        $data->created_at = $request->date.' '.$request->time;

        if($data->save()){

            $wallet->acct_balance -= $data->amount;

            if($wallet->save()){
                $trans = new Transactions();
                $trans->user_id = $user->id;
                $trans->trans_id = $data->reference;
                $trans->trans_reference = uniqid();
                $trans->amount = $data->amount;
                $trans->trans_type = "dom_transfer";
                $trans->created_at = $data->created_at;

                if($trans->save()){
                    return redirect(route('admin.users.view_transaction','dom_transfer'))->with('alert_success', 'Details Saved Successfully');
                }
            }

        }
        return back()->with('alert_error', 'Opps something went wrong');
    }

    public function paymentSubmit(Request $request){
        $validator = Validator::make($request->all(),[
            'paymentName'=>'required',
            'address'=>'required',
        ]);

        if($validator->fails()){
            return back()->with('alert_error',$validator->errors()->first());
        }

        $data = new PaymentMethod();

        $data->name = $request->paymentName;
        $data->wallet_address = $request->address;
        $data->save();

        return back()->with('alert_success','Payment Method successfully added');
    }


    public function editPaymentSubmit(Request $request){

        $validator = Validator::make($request->all(),[
            'paymentName'=>'required',
            'address'=>'required',
        ]);

        if($validator->fails()){
            return back()->with('alert_error',$validator->errors()->first());
        }

        $data = PaymentMethod::where('id',$request->id)->first();
        $data->name = $request->paymentName;
        $data->wallet_address = $request->address;

        $data->save();

        return back()->with('alert_success','Details Saved Successfully');

    }


    public function destroyMethod($id){
        $payment = PaymentMethod::find($id);
        $payment->delete();
        return back()->with('alert_success', 'Payment Method deleted successfully');
    }

}
