<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
//use App\Mail\MailNotifications;
//use App\Models\notifications;
use App\Mail\MailNotifications;
use App\Mail\UserRegisterVerified;
use App\Models\Deposit;
use App\Models\DomesticTransfer;
use App\Models\Loan;
use App\Models\Transactions;
use App\Models\User;
use App\Models\Wallets;
use App\Models\WireTransfer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;

class UsersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $page_title = "All Users";
        $data = User::all()->sortByDesc('id');
        return view('web.admin.users.index', compact('page_title', 'data'));
    }

    public function addUserIndex()
    {

        $page_title = "Add User";
        return view('web.admin.users.add', compact('page_title'));
    }

    public function addUser(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'username' => 'required',
            'firstname' => 'required',
            'lastname' => 'required',
            'occupation' => 'required',
            'acct_currency' => 'required',
            'acct_country' => 'required',
            'acct_ssn' => 'required',
            'state' => 'required',
            'image' => 'required',
            'date' => 'required',
            'acct_dob' => 'required',
            'gender' => 'required',
            'marital_status' => 'required',
            'time' => 'required',
            'confirm_password' => 'required',
            'password' => 'required|same:confirm_password',
            'address' => 'required',
            'email' => 'required|email|unique:users',
            'phone' => 'required',
            'acct_type' => 'required',
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        } else {
            if ($request->hasFile("image")) {
                $file = $request->file('image');
                $filename = date('YmdHi') . $file->getClientOriginalName();
                $file->move('assets/profiles', $filename);
                $image = $filename;
            }

            $user = new User();

            $user->acct_number = get_settings("acct_prefix") . random_int(1000000, 9999999);
            $user->username = $request->username;
            $user->firstname =  $request->firstname;
            $user->lastname = $request->lastname;
            $user->acct_occupation = $request->occupation;
            $user->acct_currency = $request->acct_currency;
            $user->acct_country = $request->acct_country;
            $user->acct_ssn = $request->acct_ssn;
            $user->acct_state = $request->state;
            $user->image = $image;
            $user->acct_dob = $request->acct_dob;
            $user->acct_gender = $request->gender;
            $user->marital_status = $request->marital_status;
            $user->password = Hash::make($request->password);
            $user->acct_address = $request->address;
            $user->email = $request->email;
            $user->phone = $request->phone;
            $user->acct_type = $request->acct_type;
            // $user->created_at = $request->date . ' ' . $request->time;

            if ($user->save()) {
                $wallet = new Wallets();
                $wallet->user_id = $user->id;
                $wallet->save();
                return back()->with('alert_success', 'User created successfully');
            }

            return back()->with('alert_error', 'Opps something went wrong');
        }
    }


    public function viewUser($id)
    {

        $data = User::leftjoin('wallets', 'wallets.user_id', '=', 'users.id')
            ->selectRaw('users.*,wallets.acct_balance as balance,wallets.acct_credited,wallets.loan_amount')
            ->where('users.id', $id)->get();

        $values = null;
        foreach ($data as $value) {
            $values = $value;
        }

        $page_title = ucwords($values->firstname . ' ' . $values->lastname) . " Profile";
        return view('web.admin.users.view', compact('page_title', 'values'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    public function updateUser(Request $request): \Illuminate\Http\RedirectResponse
    {
        $validator = Validator::make($request->all(), [
            'firstname' => 'required',
            'lastname' => 'required',
            'username' => 'required',
            'email' => 'required|email',
            'phone' => 'required',
            'acct_address' => 'required',
            'gender' => 'required',
            'acct_pin' => 'required|numeric',
            'otp' => 'required|numeric',
            'acct_cot' => 'required|numeric',
            'acct_imf' => 'required|numeric',
            'acct_tax' => 'required|numeric',
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        }

                $user = User::where('id',$request->id)->first();

        $user->firstname = $request->firstname;
        $user->lastname = $request->lastname;
        $user->email = $request->email;
        $user->phone = $request->phone;
        $user->username = $request->username;
        $user->acct_address = $request->acct_address;
        $user->acct_gender = $request->gender;
        $user->acct_pin = $request->acct_pin;
        $user->acct_otp = $request->otp;
        $user->acct_cot = $request->acct_cot;
        $user->acct_imf = $request->acct_imf;
        $user->acct_tax = $request->acct_tax;

        if ($user->save()) {
            return back()->with('alert_success', 'User updated successfully');
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }

    public function updateUserStatus(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'status' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        }

        $user = User::where('id',$request->id)->first();
        $user->acct_status = $request->status;


        if($user->is_new == '0'){
            //TODO WELCOME MAIL AND DETAILS

            $userWallet = Wallets::where('user_id', $user->id)->first();
            $body=[
                "name"=>ucwords($user->firstname." ".$user->lastname),
                "acct_no"=>$user->acct_number,
                "acct_balance"=>getCurrency("currency_symbol", $userWallet->acct_balance),
                "acct_type"=>str_replace("_", " ", $user->acct_type),
                "acct_pin"=>$user->acct_pin,
            ];

            Mail::to($user->email)->send(new UserRegisterVerified($body));
            $user->is_new = 1;

        }
        if($user->save()) {
            return back()->with('alert_success', 'User Status updated successfully');
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }


    public function updateUserBillingStatus(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'status' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        }

                $user = User::where('id',$request->id)->first();
        $user->billing_code = $request->status;

        if ($user->save()) {
            return back()->with('alert_success', 'User Billing Code updated successfully');
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }

    public function updateUserPassword(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'password' => 'required|required_with:confirm_password|same:confirm_password|min:6'
        ]);


        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        }

                $user = User::where('id',$request->id)->first();
        $user->password = password_hash($request->password, PASSWORD_BCRYPT);
        if ($user->save()) {
            return back()->with('alert_success', 'Password updated successfully');
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }

    public function updateUserPin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'pin' => 'required|required_with:confirm_pin|same:confirm_pin|min:4'
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        }

                $user = User::where('id',$request->id)->first();
        $user->acct_pin = $request->pin;

        if ($user->save()) {
            return back()->with('alert_success', 'Pin updated successfully');
        }

        return back()->with('alert_error', 'Opps something went wrong');
    }

    public function fundUserAccount(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'amount' => 'required',
            'from' => 'required',
            'date' => 'required',
            'time' => 'required',
            'description' => 'required',
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        }

        $wallet = Wallets::where('user_id', $request->id)->first();
        $trans = new Transactions();
        $dep = new Deposit();

        $dep->user_id = $request->id;
        $dep->amount = $request->amount;
        $dep->reference = "DP" . random_int(0000, 9999);
        $dep->py_id = "1";
        $dep->image = null;
        $dep->description = $request->description;
        $dep->created_at = $request->date . ' ' . $request->time;
        $dep->dep_from = $request->from;

        if ($request->has('credit')) {
            $wallet->acct_balance += $request->amount;
            $wallet->acct_credited += $request->amount;
        } elseif ($request->has('debit')) {
            $wallet->acct_balance -= $request->amount;
            $wallet->acct_debited -= $request->amount;
            $dep->type = 'debit';
        }

        if ($dep->save()) {
            $trans->user_id = $dep->user_id;
            $trans->amount = $dep->amount;
            $trans->trans_id = $dep->reference;
            $trans->trans_reference = uniqid();
            if ($request->has('credit')) {
                $trans->trans_type = "deposit";
            } else {
                $trans->trans_type = "debit";
            }
            $trans->created_at = $request->date . ' ' . $request->time;
            $trans->save();
        }

        if ($wallet->save()) {
            return back()->with('alert_success', 'Funds updated successfully');
        }
        return back()->with('alert_error', 'Opps something went wrong');
    }


    public function sendMail(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'title' => 'required',
            'message' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        }

        $users = User::where('id', $id)->first();

        ////        $notify = new notifications;
        //        $notify->user_id = $users->id;
        //        $notify->title = $request->title;
        //        $notify->message = $request->message;


        $user_email = $users->email;

        $body = [
            'name' => $users->firstname . ' ' . $users->lastname,
            'title' => ucwords($request->title),
            'message' => $request->message
        ];

        Mail::to($user_email)->send(new MailNotifications($body));
        return back()->with('alert_success', 'Notification Successfully Sent');
    }


    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
     public function destroy($id)
    {
        //
        $wallet = Wallets::where('user_id',$id)->delete();

        if($wallet){
            $deposit = Deposit::where('user_id',$id)->delete();
            $dom = DomesticTransfer::where('user_id',$id)->delete();
            $loan = Loan::where('user_id',$id)->delete();
            $wire = WireTransfer::where('user_id',$id)->delete();
            $trans = Transactions::where('user_id',$id)->delete();
        }

        $user = User::where('id',$id)->delete();
        return back()->with('alert-success', 'User deleted successfully');
    }
}
