<?php

namespace App\Http\Controllers\Users\Auth;

use App\Http\Controllers\Controller;
use App\Mail\userPIN;
use App\Mail\ForgetPasswordMail;
use Hash;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;

class LoginController extends Controller
{
    public function __construct()
    {
        $this->isAdminRedirect = route('admin.dashboard');
    }

    #WEB & APP
    public function login(Request $request)
    {
        //
        $validator = Validator::make($request->all(), [
            'acct_username' => 'required',
            'password' => 'required',
        ]);

        if ($validator->fails()) {
            return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                "errors" => $validator->messages(),
                "status" => 404,
            ]);
        }

        $log = Auth::attempt([
            'username' => $request->acct_username,
            'password' => $request->password
        ]);

        if ($log) {
            if (auth()->user()->role_id == 2) {
                if($request->isMobile) {
                    return [
                        "status" => 200,
                        "msg" => "Successfully login",
                        "redirect" => $this->isAdminRedirect
                    ];
                }else{
                    return redirect($this->isAdminRedirect)->with("success_alert","Successfully logged in");
                }
            }
        
            if(Auth::user()->acct_status == '2'){
                Auth::logout();
                if($request->isMobile){
                    return post_response($request->isMobile, "alert_error", "Your account is still under review", [
                        "status" => 404,
                    ]);
                }else{
                    return redirect()->back()->with("alert_error","Your account is still under review");
                }
            }

            if(Auth::user()->acct_status == '3'){
                Auth::logout();
                if($request->isMobile){
                    return post_response($request->isMobile, "alert_error", "Your account have been suspended due to unusual activities in your account, kindly contact the customer support or visit the branch for reactivation!", [
                        "status" => 404,
                    ]);
                }else{
                    return redirect()->back()->with("alert_error","Your account have been suspended due to unusual activities in your account, kindly contact the customer support or visit the branch for reactivation!");
                }
            }
            

            Session::put("usePIN", ["id" => Auth::user()->id, "password" => $request->password]);

            if (get_settings('mailing_code')) {
                $this->resend_otp_code();
            }

            Auth::logout();

            if ($request->isMobile) {
                return [
                    "status" => 200,
                    "msg" => "Successfully login! please enter your OTP code",
                    "redirect" => route('m.useOTP')
                ];
            } else {
                return redirect(route('d.useOTP'))->with('Successfully login! please enter your OTP code');
            }
        }

        return post_response($request->isMobile, "alert_error", 'Invalid login details', [
            "errors" => $validator->messages(),
            "status" => 404,
        ]);
    }

    public function submitPIN(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'pin' => 'required'
        ]);
        if ($validator->fails()) {
            return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                "errors" => $validator->messages(),
                "status" => 404,
            ]);
        } else {
            $user = User::find(session('usePIN')["id"]);
            if (get_settings('mailing_code') == '1') {
                if ($user->acct_otp == $request->pin) {
                    $correct = true;
                } else {
                    $correct = false;
                }
            } else {
                if ($user->acct_pin == $request->pin) {
                    $correct = true;
                } else {
                    $correct = false;
                }
            }
            if ($correct) {
                $log = Auth::attempt([
                    'acct_number' => $user->acct_number,
                    'password' => session('usePIN')["password"]
                ]);
                if ($log) {
                    Session::remove('usePIN');
                    if ($request->isMobile) {
                        return [
                            "status" => 200,
                            "msg" => "Successfully logged in",
                            "redirect" => route('m.user.dashboard')
                        ];
                    } else {
                        return redirect(route('d.user.dashboard'))->with('Successfully login!');
                    }
                }
            } else {
                return post_response($request->isMobile, "alert_error", 'Invalid pin', [
                    "errors" => $validator->messages(),
                    "status" => 404,
                ]);
            }
        }
    }

    public function resend_otp_code()
    {
        $user = User::find(session('usePIN')["id"]);
        $user->acct_otp=random_int(100000, 999999);
        $user->save();
        $body = [
            "name" => $user->firstname . " " . $user->lastname,
            'otp_pin' => $user->acct_otp,
            'email' => $user->email,
            "date" => date("Y-m-d H:i:s")
        ];
        Mail::to($user->email)->send(new userPIN($body));
        return back()->with("alert_success","Successfully resend pin");
    }
    
    public function  reset_password(Request $request){
        $validator = Validator::make($request->all(), [
            'new_password' =>'required',
            'user_id'=>'required',
            'confirm_password' =>'required|same:new_password',
        ]);

        if($validator->fails()){
            return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                "errors" => $validator->messages(),
                "status" => 404,
            ]);
        }else{
            $user = User::where("id",$request->user_id)->first();
            $user->password = Hash::make($request->new_password);
            $user->forget_password_token ="";
            $user->save();
            return post_response($request->isMobile, "alert_success", "Password changed successfully! please login", [
                "status" => 200,
                "msg" => "Password changed successfully! please login",
                "redirect" => route('m.login')
            ]);
        }
    }
    
    public function forgetpassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            "email" => "required|email"
        ]);
        if ($validator->fails()) {
            return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                "errors" => $validator->messages(),
                "status" => 404,
            ]);
        } else {
            $user = User::where('email', $request->email)->first();
            if ($user) {
                $user->forget_password_token = uniqid(20);
                $user->save();

                $body = [
                    "url_a" => $request->isMobile ? route('m.reset_password',["token"=>$user->forget_password_token,"u"=>$user->email]) : "",
                    "name"  => $user->firstname . " " . $user->lastname, 
                ];

                Mail::to($user->email)->send(new ForgetPasswordMail($body));
                return post_response($request->isMobile, "alert_success", [
                    "status" => 200,
                    "msg" => "Reset Password link has been sent to your email address"
                ]);
            } else {
                return post_response($request->isMobile, "alert_error", "Invalid email address", [
                    "errors" => $validator->messages(),
                    "status" => 404,
                ]);
            }
        }
    }

}
