<?php

namespace App\Http\Controllers\Users\Auth;

use App\Http\Controllers\Controller;
use App\Mail\UserRegister;
use App\Models\User;
use App\Models\Wallets;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;

class RegisterController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $page_title = 'Register';
        return view('auth.register',compact('page_title'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'username' => 'required',
            'firstname' => 'required',
            'lastname' => 'required',
            'occupation' => 'required',
            'acct_currency' => 'required',
            'acct_country' => 'required',
            'acct_ssn' => 'required',
            'zip_code'=>'required',
            'state' => 'required',
            'image' => 'required',
            'acct_dob' => 'required',
            'gender' => 'required',
            'marital_status' => 'required',
            'confirm_password' => 'required',
            'password' => 'required|same:confirm_password',
            'address' => 'required',
            'email' => 'required|email|unique:users',
            'phone' => 'required',
            'acct_type' => 'required',
        ]);

        if ($validator->fails()) {
            return back()->with('alert_error', $validator->messages()->first());
        } else {

            if ($request->hasFile("image")) {
                $file = $request->file('image');
                $filename = date('YmdHi') . $file->getClientOriginalName();
                $file->move('assets/profiles', $filename);
                $image = $filename;
            }

            $user = new User();

            $user->acct_number = get_settings("acct_prefix") . random_int(1000000, 9999999);
            $user->username = $request->username;
            $user->firstname =  $request->firstname;
            $user->lastname = $request->lastname;
            $user->acct_occupation = $request->occupation;
            $user->acct_currency = $request->acct_currency;
            $user->acct_country = $request->acct_country;
            $user->acct_ssn = $request->acct_ssn;
            $user->acct_state = $request->state;
            $user->zip_code = $request->zip_code;
            $user->image = $image;
            $user->acct_dob = $request->acct_dob;
            $user->acct_gender = $request->gender;
            $user->marital_status = $request->marital_status;
            $user->password = Hash::make($request->password);
            $user->acct_address = $request->address;
            $user->email = $request->email;
            $user->is_new = 0;
            $user->acct_type = $request->acct_type;
            $user->created_at = $request->date . " " . $request->time;

            if ($user->save()) {
                $wallet = new Wallets();
                $wallet->user_id = $user->id;
                $wallet->save();

                $body=[
                    "name"=>ucwords($request->firstname). " ". ucwords($request->lastname),
                ];
                //TODO SEND USER MAIL
                Mail::to($user->email)->send(new UserRegister($body));

                return back()->with('alert_success', 'Successfully created your account !Your account is under review');
            }

            return back()->with('alert_error', 'Opps something went wrong');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
