<?php

namespace App\Http\Controllers\Users;

use App\Http\Controllers\Controller;
use App\Mail\OtpMail;
use App\Models\DomesticTransfer;
use App\Models\Transactions;
use App\Models\User;
use App\Models\Wallets;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;

class DomesticController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return string
     */
    public function store(Request $request)
    {
        //
        $validator = Validator::make($request->all(), [
            'amount'=>'required',
            'acct_name'=> 'required',
            'bank_name'=> 'required',
            'acct_number'=> 'required',
            'acct_type'=> 'required',
            'acct_remark'=> 'required',
        ]);

        if($validator->fails()){
            if($request->isMobile) {
                return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                    "errors" => $validator->messages(),
                    "status" => 404,
                ]);
            }

            $data = array(
                'status' => 'error',
                'msg' =>$validator->messages()->first()
            );

            return json_encode($data);
        }


        //TODO CHECK AMOUNT BALANCE
        if($request->amount > authUser('balance') || $request->amount <= 0){
            $data = array(
                'status' => 'error',
                'msg' =>($request->amount <= 0) ? 'Invalid Amount': 'Insufficient funds'
            );

            return json_encode($data);
        }
        //TODO SAVE DOMESTIC TRANSFER
        $dom = new DomesticTransfer();
        $dom->user_id = authUser('id');
        $dom->reference = "DT".random_int(0000,9999);
        $dom->amount = $request->amount;
        $dom->bank_name = $request->bank_name;
        $dom->acct_name = $request->acct_name;
        $dom->acct_number = $request->acct_number;
        $dom->acct_type = $request->acct_type;
        $dom->acct_remark = $request->acct_remark;

        if ($dom->save()) {
            $user = User::where('id',authUser("id"))->first();

            $user->acct_otp = random_int(000000,999999);

            if($user->save()){
                //Todo mail function
                $code = $user->acct_otp;
                $body = [
                    'name'=>authUser("firstname")." ".authUser("lastname"),
                    'amount'=>$request->amount,
                    'otp_code'=>$code
                ];

                Mail::to(authUser('email'))->send(new OtpMail($body));

            }

            $data = $request->input();

            return json_encode([
                'status'=>'success',
                'msg'=>$data,
                'amount_to_get'=>getCurrency('currency_symbol',$request->amount),
                'reference_id'=> $dom->reference
            ]);
        }

        $data = [
            'status' =>'error',
            'msg'=>'Opps something went wrong',
        ];
        return json_encode($data);

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request)
    {
        //
        $validator = Validator::make($request->all(), [
            'otp_code'=>'required|numeric'
            ]);

        if ($validator->fails()){
            if($request->isMobile) {
                return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                    "errors" => $validator->messages(),
                    "status" => 404,
                ]);
            }

            $data = array(
                'status' => 'error',
                'msg' =>$validator->messages()->first()
            );

            return json_encode($data);
        }

        if($request->otp_code !== authUser('acct_otp')){
            $data = array(
                'status' => 'error',
                'msg' =>'Invalid Otp Code'
            );
            return json_encode($data);
        }

        $id = $request->ref_id;
        $dom = DomesticTransfer::where('reference',$id)->first();

        //TODO DEDUCT FROM WALLET BALANCE
        $wallet = Wallets::where('user_id',authUser('id'))->first();
        $wallet->acct_balance -= $dom->amount;

        if($wallet->save()){
            //TODO SAVE DOMESTIC TRANSACTION
            $trans = new Transactions();
            $trans->user_id = authUser("id");
            $trans->trans_id = $id;
            $trans->trans_reference = uniqid();
            $trans->amount = $dom->amount;
            $trans->trans_type = "dom_transfer";

            if ($trans->save()) {
                $dom->status = 'pending';
                if($dom->save()) {
                    //TODO REDIRECT IF SUCCESS
                    return post_response(1, "alert_success", "Your transaction is on process", [
                        "status" => 200,
                        'redirect' =>CheckDevice('user.transaction',true)
                    ],
                        CheckDevice('user.transaction')
                    );
                }
            }


        }

        return post_response($request->isMobile, "alert_error", "Opps something went wrong",
            [
                'status' => 404,
                'redirect'=>"/"
            ]);

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
