<?php

namespace App\Http\Controllers\Users;

use App\Http\Controllers\Controller;
use App\Models\Deposit;
use App\Models\PaymentMethod;
use App\Models\Transactions;
use App\Models\User;
use Dflydev\DotAccessData\Data;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

class UserController extends Controller
{

    //TODO UPDATE PROFILE
    public function updateProfile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'username' => 'required',
            'firstname' => 'required',
            'lastname' => 'required',
            'acct_occupation' => 'required',
            'acct_dob' => 'required',
            'acct_gender' => 'required',
            'marital_status' => 'required',
            'acct_address' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'acct_type' => 'required',
        ], [], [
            "acct_occupation" => "account occupation",
            "acct_gender" => "gender",
            "acct_address" => "account address",
            "acct_dob" => "date of birth",
            "acct_country" => "country",
            "acct_state" => "state",
            "acct_type" => "account type",
            "acct_currency" => "account currency",
        ]);


        if ($validator->fails()) {
            return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                "errors" => $validator->messages(),
                "status" => 404,
            ]);
        }

        $user = User::find(authUser("id"));
        $user->username = $request->username;
        $user->firstname =  $request->firstname;
        $user->lastname = $request->lastname;
        $user->acct_occupation = $request->acct_occupation;
        $user->acct_dob = $request->acct_dob;
        $user->acct_gender = $request->acct_gender;
        $user->marital_status = $request->marital_status;
        $user->acct_address = $request->acct_address;
        $user->email = $request->email;
        $user->phone = $request->phone;
        $user->acct_type = $request->acct_type;

        //CHANGE PASSWORD WITH PROFILE FOR MOBILE, EXCLUDED FROM WEB
        if ($request->isMobile) {
            if ($request->new_password || $request->current_password || $request->old_password) {
                $response = $this->changePassword($request);
                if ($response["status"] == "404") return $response;
            }
        }
        //CHANGE PIN WITH PROFILE FOR MOBILE, EXCLUDED FROM WEB
        if ($request->isMobile) {
            if ($request->new_pin || $request->current_pin || $request->old_pin) {
                $response = $this->changePin($request);
                if ($response["status"] == "404") return $response;
            }
        }

        if ($user->save()) {
            return post_response($request->isMobile, "alert_success", "Successfully updated profile", [
                "status" => 200,
            ]);
        }

        return post_response($request->isMobile, "alert_error", "Opps something went wrong", [
            "status" => 400,
        ]);
    }


    //TODO UPDATE SECURITY PASSWORD
    public function changePassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            "current_password" => "required",
            "new_password" => "required",
            "confirm_password" => "required|same:new_password",
        ]);
        if ($validator->fails()) {
            return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                "errors" => $validator->messages(),
                "status" => 404,
            ]);
        }

        $user = User::find(authUser("id"));
        if (Hash::check($request->current_password, $user->password)) {
            $user->password = Hash::make($request->new_password);
            if ($user->save()) {
                return post_response($request->isMobile, "alert_success", "Successfully updated password", [
                    "status" => 200,
                ]);
            }
        }

        return post_response($request->isMobile, "alert_error", "Incorrect password", [
            "status" => 404,
        ]);
    }

    //TODO UPDATE SECURITY PIN
    public function changePin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            "current_pin" => "required",
            "new_pin" => "required",
            "confirm_pin" => "required|same:new_pin",
        ]);
        if ($validator->fails()) {
            return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                "errors" => $validator->messages(),
                "status" => 404,
            ]);
        }

        $user = User::find(authUser("id"));
        if ($request->current_pin === $user->acct_pin) {
            $user->acct_pin = $request->new_pin;
            if ($user->save()) {
                return post_response($request->isMobile, "alert_success", "Successfully updated account pin", [
                    "status" => 200,
                ]);
            }
        }
        return post_response($request->isMobile, "alert_error", "Incorrect account pin", [
            "status" => 404,
        ]);

    }

    //TODO UPDATE PROFILE PICTURE
    public function updateProfilePicture(Request $request){
        $validator = Validator::make($request->all(), [
            'image' => 'required'
        ]);

        if ($validator->fails()) {
            return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                "errors" => $validator->messages(),
                "status" => 404,
            ]);
        }

        if($request->file('image')){
            $file= $request->file('image');
            $filename= date('YmdHi').$file->getClientOriginalName();
            $file-> move('assets/profiles', $filename);
            $image = $filename;
        }else{
            $image = $request->imageFile;
        }

        $user = User::find(authUser("id"));

        $user->image = $image;

        if($user->save()){
            return post_response($request->isMobile, "alert_success", "Successfully updated profile picture", [
                "status" => 200,
            ]);
        }

        return post_response($request->isMobile, "alert_error", "Opps something went wrong, Kinldy try again", [
            "status" => 404,
        ]);

    }


    //TODO TO FETCH PAYMENT METHOD
    public function fetchPayment(Request $request)
    {
        if (empty($request->payment_method)) {
            return 0;
        }
        $data = PaymentMethod::where('id', $request->payment_method)->first();

        $value = $data->wallet_address;
        $walletAdrs = "https://api.qrserver.com/v1/create-qr-code/?data=" . $data->wallet_address . "&amp;size=200x200";

        $dataVlue['msg'] = $value;
        $dataVlue['wallet'] = $walletAdrs;


        return json_encode($dataVlue);
    }


}
