<?php

namespace App\Http\Controllers\Users;

use App\Http\Controllers\Controller;
use App\Mail\OtpMail;
use App\Models\Transactions;
use App\Models\User;
use App\Models\Wallets;
use App\Models\WireTransfer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;

class WireController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return string
     */
    //TODO SEND WIRE TRANSACTION
    public function store(Request $request)
    {
        //
      if($request->isProcess == '1'){
          $validator = Validator::make($request->all(),[
              'amount'=>'required|numeric',
              'bank_name'=> 'required',
              'acct_name'=> 'required',
              'acct_number'=> 'required',
              'acct_type'=> 'required',
              'acct_country'=> 'required',
              'acct_swift'=> 'required',
              'acct_routing'=> 'required',
              'acct_remark'=> 'required',
          ]);


          if ($validator->fails()) {
              if($request->isMobile) {
                  return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                      "errors" => $validator->messages(),
                      "status" => 404,
                  ]);
              }

              $data = array(
                  'status' => 'error',
                  'msg' =>$validator->messages()->first()
              );

              return json_encode($data);
          }

          //TODO CHECK AMOUNT BALANCE
          if($request->amount > authUser('balance') || $request->amount <= 0){
              $data = array(
                  'status' => 'error',
                  'msg' =>($request->amount <= 0) ? 'Invalid Amount': 'Insufficient funds'
              );

              return json_encode($data);
          }

          //Todo Wire Transfer

          $data = new WireTransfer();
          $data->user_id = authUser('id');
          $data->reference = "WT".random_int(0000,9999);
          $data->amount = $request->amount;
          $data->bank_name = $request->bank_name;
          $data->acct_name = $request->acct_name;
          $data->acct_number = $request->acct_number;
          $data->acct_type = $request->acct_type;
          $data->acct_country = $request->acct_country;
          $data->acct_swift = $request->acct_swift;
          $data->acct_routing = $request->acct_routing;
          $data->acct_remark = $request->acct_remark;

          if($data->save()){
                //TODO Check Billing Code
              if(get_settings('billing_code') == '1' && authUser('billing_code') == '1'){
                  $data->billing_page = "cot";
              }else{
                  $user = User::where('id',authUser("id"))->first();
                  $user->acct_otp = random_int(000000,999999);

                  if($user->save()){
                      //Todo mail function
                      $code = $user->acct_otp;
                      $body = [
                          'name'=>authUser("firstname")." ".authUser("lastname"),
                          'amount'=>$request->amount,
                          'otp_code'=>$code
                      ];

                      Mail::to(authUser('email'))->send(new OtpMail($body));

                  }

                  $data->billing_page = "success";
              }
              $data->status = 'success';
              $data->amount_to = getCurrency('currency_symbol',$data->amount);
              return json_encode($data);
          }

          $data = array(
              'status' => 'error',
              'msg' => 'Opps something went wrong'
          );
          return json_encode($data);

      }

        return post_response($request->isMobile, "alert_error", "Opps something went wrong",
            [
                'status' => 404,
                'redirect'=>"/"
            ]);

    }

    //TODO COT CODE TRANSACTION
    public function cotTransfer(Request $request){
        $validator = Validator::make($request->all(), [
            'cot_pin'=>'required|numeric',
        ]);

        if ($validator->fails()) {
            if($request->isMobile) {
                return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                    "errors" => $validator->messages(),
                    "status" => 404,
                ]);
            }

            $data = array(
                'status' => 'error',
                'msg' =>$validator->messages()->first()
            );

            return json_encode($data);
        }

        if($request->cot_pin !== authUser('acct_cot')){
            $data = array(
                'status' => 'error',
                'msg' =>'Invalid COT Code'
            );
            return json_encode($data);
        }

        $data = array(
            'status' => 'success',
            'page' =>'tax'
        );

        return json_encode($data);


    }

    //TODO TAX CODE TRANSACTION
    public function taxTransfer(Request $request){
        $validator = Validator::make($request->all(), [
            'tax_pin'=>'required|numeric',
        ]);

        if ($validator->fails()) {
            if($request->isMobile) {
                return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                    "errors" => $validator->messages(),
                    "status" => 404,
                ]);
            }

            $data = array(
                'status' => 'error',
                'msg' =>$validator->messages()->first()
            );

            return json_encode($data);
        }

        if($request->tax_pin !== authUser('acct_tax')){
            $data = array(
                'status' => 'error',
                'msg' =>'Invalid TAX Code'
            );
            return json_encode($data);
        }

        $data = array(
            'status' => 'success',
            'page' =>'imf'
        );

        return json_encode($data);


    }

    //TODO IMF CODE TRANSACTION
    public function imfTransfer(Request $request){

        $validator = Validator::make($request->all(), [
            'imf_tax'=>'required|numeric',

        ]);

        if ($validator->fails()) {
            if($request->isMobile) {
                return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                    "errors" => $validator->messages(),
                    "status" => 404,
                ]);
            }

            $data = array(
                'status' => 'error',
                'msg' =>$validator->messages()->first()
            );

            return json_encode($data);
        }

        if($request->imf_tax !== authUser('acct_imf')){
            $data = array(
                'status' => 'error',
                'msg' =>'Invalid IMF Code'
            );
            return json_encode($data);
        }

        $user = User::where('id',authUser("id"))->first();
        $user->acct_otp = random_int(000000,999999);

        if($user->save()){
            //Todo mail function
            $code = $user->acct_otp;
            $body = [
                'name'=>authUser("firstname")." ".authUser("lastname"),
                'amount'=>$request->amount,
                'otp_code'=>$code
            ];

            Mail::to(authUser('email'))->send(new OtpMail($body));

        }

        $data = $request->input();

        return json_encode([
            'status'=>'success',
            'msg'=>$data,
            'amount_to_get'=>getCurrency('currency_symbol',$request->amount)
        ]);


    }



    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    //TODO UPDATE TRANSACTION
    public function update(Request $request)
    {
        //
        $validator = Validator::make($request->all(), [
            'ref_id'=>'required',
            'otp_code'=> 'required',
        ]);

        //TODO VALIDATION
        if ($validator->fails()) {
            if($request->isMobile) {
                return post_response($request->isMobile, "alert_error", $validator->messages()->first(), [
                    "errors" => $validator->messages(),
                    "status" => 404,
                ]);
            }

            $data = array(
                'status' => 'error',
                'msg' =>$validator->messages()->first()
            );

            return json_encode($data);
        }

        if($request->otp_code !== authUser('acct_otp')){
            $data = array(
                'status' => 'error',
                'msg' =>'Invalid Otp Code'
            );
            return json_encode($data);
        }




        $id = $request->ref_id;
        // TODO SAVE DATA INTO WIRE TRANSFER
        $wire_trans = WireTransfer::where('reference',$id)->first();

        //TODO DEDUCT FROM WALLET BALANCE
        $wallet = Wallets::where('user_id',authUser('id'))->first();
        $wallet->acct_balance -= $wire_trans->amount;

        if($wallet->save()) {
            //TODO SAVE WIRE TRANSACTION
            $trans = new Transactions();
            $trans->user_id = authUser("id");
            $trans->trans_id = $id;
            $trans->trans_reference = uniqid();
            $trans->amount = $wire_trans->amount;
            $trans->trans_type = "wire_transfer";

            if ($trans->save()) {
                $wire_trans->status = 'pending';
                if ($wire_trans->save()) {
                    //TODO REDIRECT IF SUCCESS
                    return post_response(1, "alert_success", "Your transaction is on process", [
                        "status" => 200,
                        'redirect' => CheckDevice('user.transaction', true)
                    ],
                        CheckDevice('user.transaction')
                    );
                }
            }
        }
        return post_response($request->isMobile, "alert_error", "Opps something went wrong",
            [
                'status' => 404,
                'redirect'=>"/"
            ]);

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
