<?php


use App\Http\Controllers\Admin\AdminController;
use App\Http\Controllers\Admin\AdminSettingController;
use App\Http\Controllers\Admin\AdminSupportTicketController;
use App\Http\Controllers\Admin\CardsController;
use App\Http\Controllers\Admin\LoanController;
use App\Http\Controllers\Admin\TransactionsController;
use App\Http\Controllers\Admin\UsersController;
use App\Http\Controllers\Admin\TransferController;

Route::middleware(['isAdmin','auth'])->group(function () {
    Route::prefix('panel/admin')->group(function () {
        Route::get('dashboard', [AdminController::class, 'dashboard'])->name('admin.dashboard');
        //TODO ADMIN SETTINGS
        Route::resource('settings',AdminSettingController::class);

        //TODO PAYMENT METHOD
        Route::get('payment/method',[TransferController::class,"payment_methodView"])->name('admin.users.payment_method');

        //TODO DELETE PAYMENT METHOD
        Route::get('payment/method/delete/{id}',[TransferController::class,'destroyMethod'])->name('admin.delete.method');
        Route::post('payment/method',[TransferController::class,'paymentSubmit'])->name('admin.payment.method');
        Route::post('payment/method/edit',[TransferController::class,'editPaymentSubmit'])->name('admin.edit.method');

        Route::prefix('users')->group(function () {
            Route::get('/', [UsersController::class, 'index'])->name('admin.users');
            //TODO ADD USERS DETAILS
            Route::get('user/add',[UsersController::class,'addUserIndex'])->name('admin.users.add');
            Route::post('user/add',[UsersController::class,'addUser'])->name('admin.users.addSave');
            //TODO VIEW USERS DETAILS
            Route::get('view/{id}', [UsersController::class, 'viewUser'])->name('admin.users.view');
             //TODO DELETE USER
            Route::get('delete/{id}', [UsersController::class, 'destroy'])->name('admin.users.delete');
            //TODO UPDATE USERS DETAILS
            Route::post('view/update_user', [UsersController::class, 'updateUser'])->name('admin.users.update');
            //TODO UPDATE ACCOUNT STATUS
            Route::post('update_user_status', [UsersController::class, 'updateUserStatus'])->name('admin.users.update_status');
            //TODO UPDATE USER BILLING STATUS
            Route::post('update_user_billing_status', [UsersController::class, 'updateUserBillingStatus'])->name('admin.users.update_billing_status');
            //TODO CHANGE USER PASSWORD
            Route::post('update_user_password', [UsersController::class, 'updateUserPassword'])->name('admin.users.update_password');
            //TODO CHANGE USER PIN
            Route::post('update_user_pin', [UsersController::class, 'updateUserPin'])->name('admin.users.update_pin');
            //TODO FUND USER ACCOUNT
            Route::post('fund_user_account', [UsersController::class, 'fundUserAccount'])->name('admin.users.fund_account');
            Route::get('referrals/{id}', [UsersController::class, 'viewReferrals'])->name('admin.users.viewReferrals');

            //TODO SEND MAIL TO USERS
            Route::post('view/mail/{id}',[UsersController::class,'sendMail'])->name('admin.users.mail');

            //TODO VIEW ALL TRANSACTION
            Route::get('view/all/{id}', [TransactionsController::class, 'index'])->name('admin.users.view_transaction');

            //TODO VIEW CREDIT TRANSACTION
            Route::get('view/trans/credit/{id}', [TransactionsController::class, 'view_credit'])->name('admin.users.view_credit');
            Route::post('view/trans/credit/{id}/save', [TransactionsController::class, 'save_credit'])->name('admin.users.save_credit');
            //TODO VIEW WIRE TRANSACTION
            Route::get('view/trans/wire_transfer/{id}', [TransactionsController::class, 'view_wire_transfer'])->name('admin.users.view_wire_transfer');
            Route::post('view/trans/wire_transfer/{id}/save', [TransactionsController::class, 'save_wire'])->name('admin.users.save_wire');
            //TODO VIEW DOM TRANSACTION
            Route::get('view/trans/dom_transfer/{id}', [TransactionsController::class, 'view_dom_transfer'])->name('admin.users.view_dom_transfer');
            Route::post('view/trans/dom_transfer/{id}/save', [TransactionsController::class, 'save_dom'])->name('admin.users.save_dom');
            //TODO VIEW DEBIT TRANSACTION
            Route::get('view/trans/debit/{id}', [TransactionsController::class, 'view_debit'])->name('admin.users.view_debit');
            Route::post('view/trans/debit/{id}/save', [TransactionsController::class, 'save_debit'])->name('admin.users.save_debit');
            //TODO DELETE TRANSACTION
            Route::get('delete/trans/{type}/{id}', [TransactionsController::class, 'delete_trans'])->name('admin.users.delete_trans');
            #TRANSFER
            //TODO WIRE TRANSFER FROM ADMIN
            Route::get('wire/transfer',[TransferController::class,"wire_transfer"])->name('admin.users.wire_transfer');
            Route::post('wire/transfer/send',[TransferController::class,"wire_transfer_send"])->name('admin.users.wire_transfer_send');
            //TODO DOM TRANSFER FROM ADMIN
            Route::get('dom/transfer',[TransferController::class,"domTransfer"])->name('admin.users.dom_transfer');
            Route::post('dom/transfer/send',[TransferController::class,"domTransferSave"])->name('admin.users.dom_transfer_save');

            //TODO SUPPORT TICKET
            Route::get('support/ticket',[AdminSupportTicketController::class, 'index'])->name('admin.users.support_ticket');
       
            //TODO ADMIN LOAD
            Route::get('loan',[LoanController::class, 'index'])->name('admin.loan');
            Route::get('loan/delete/{id}',[LoanController::class, 'delete'])->name('admin.loan.delete');
            Route::get('loan/{id}',[LoanController::class, 'view'])->name('admin.loan.view');
            Route::post('loan/update/{id}',[LoanController::class, 'update'])->name('admin.loan.update');

        });

        Route::group(['prefix' => 'cards'], function () {
            //TODO USER CARD
            Route::get('/',[CardsController::class, 'index'])->name('admin.user_card');
            Route::post('/create',[CardsController::class, 'store'])->name('admin.user_card_create');

        });
    });
});
